@@ -48,6 +48,8 @@ private:
 
 private slots:
     void resetMaxValue();
+    void setLinearScale();
+    void setDbScale();
     void sourceChanged(QString source);
     void updateValues(float value);
 };
